# oracle_to_python

This package has equivalent NULL functions in Python as are there in Oracle

## This package oracle_to_python.nulls has below functions.

* nvl
* nvl2
* nullif

pip install oracle_to_python

## Module name

nulls

